COMPMID-444: Add support for QS8/QS16 NEON Arithmetic Add/Sub/Mul.

Change-Id: Ia482498688ca1884272b5062e3415e736e03d36f
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/80448
Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
diff --git a/tests/validation/Reference.h b/tests/validation/Reference.h
index 902d04d..3ad9814 100644
--- a/tests/validation/Reference.h
+++ b/tests/validation/Reference.h
@@ -107,26 +107,28 @@
     static RawTensor compute_reference_accumulate_weighted(const TensorShape &shape, float alpha);
     /** Compute reference arithmetic addition.
      *
      * @param[in] shape          Shape of the input and output tensors.
      * @param[in] dt_in0         Data type of first input tensor.
      * @param[in] dt_in1         Data type of second input tensor.
      * @param[in] dt_out         Data type of the output tensor.
      * @param[in] convert_policy Overflow policy of the operation.
      *
      * @return Computed raw tensor.
      */
-    static RawTensor compute_reference_arithmetic_addition(const TensorShape &shape, DataType dt_in0, DataType dt_in1, DataType dt_out, ConvertPolicy convert_policy);
+    static RawTensor compute_reference_arithmetic_addition(const TensorShape &shape, DataType dt_in0, DataType dt_in1, DataType dt_out, ConvertPolicy convert_policy, int fixed_point_position = 0);
     /** Compute reference arithmetic subtraction.
      *
      * @param[in] shape          Shape of the input and output tensors.
      * @param[in] dt_in0         Data type of first input tensor.
      * @param[in] dt_in1         Data type of second input tensor.
      * @param[in] dt_out         Data type of the output tensor.
      * @param[in] convert_policy Overflow policy of the operation.
      *
      * @return Computed raw tensor.
      */
-    static RawTensor compute_reference_arithmetic_subtraction(const TensorShape &shape, DataType dt_in0, DataType dt_in1, DataType dt_out, ConvertPolicy convert_policy);
+    static RawTensor compute_reference_arithmetic_subtraction(const TensorShape &shape, DataType dt_in0, DataType dt_in1, DataType dt_out, ConvertPolicy convert_policy, int fixed_point_position = 0);
     /** Compute reference bitwise and.
      *
      * @param[in] shape Shape of the input and output tensors.
@@ -107,26 +107,28 @@
     /** Compute reference arithmetic addition.
      *
-     * @param[in] shape          Shape of the input and output tensors.
-     * @param[in] dt_in0         Data type of first input tensor.
-     * @param[in] dt_in1         Data type of second input tensor.
-     * @param[in] dt_out         Data type of the output tensor.
-     * @param[in] convert_policy Overflow policy of the operation.
+     * @param[in] shape                Shape of the input and output tensors.
+     * @param[in] dt_in0               Data type of first input tensor.
+     * @param[in] dt_in1               Data type of second input tensor.
+     * @param[in] dt_out               Data type of the output tensor.
+     * @param[in] convert_policy       Overflow policy of the operation.
+     * @param[in] fixed_point_position (Optional) Number of bits for the fractional part of the fixed point numbers
      *
      * @return Computed raw tensor.
@@ -107,26 +107,28 @@
     /** Compute reference arithmetic subtraction.
      *
-     * @param[in] shape          Shape of the input and output tensors.
-     * @param[in] dt_in0         Data type of first input tensor.
-     * @param[in] dt_in1         Data type of second input tensor.
-     * @param[in] dt_out         Data type of the output tensor.
-     * @param[in] convert_policy Overflow policy of the operation.
+     * @param[in] shape                Shape of the input and output tensors.
+     * @param[in] dt_in0               Data type of first input tensor.
+     * @param[in] dt_in1               Data type of second input tensor.
+     * @param[in] dt_out               Data type of the output tensor.
+     * @param[in] convert_policy       Overflow policy of the operation.
+     * @param[in] fixed_point_position (Optional) Number of bits for the fractional part of the fixed point numbers
      *
      * @return Computed raw tensor.